artella-plugins-getdependencies
============================================================

Artella Plugin that allows to recursively download all dependencies of a DCC file.

.. image:: https://github.com/artella/artella-plugins-getdependencies/workflows/Python%20package/badge.svg
    :target: https://github.com/artella/artella-plugins-getdependencies/actions?query=workflow%3A%22Python+package%22

.. image:: https://github.com/artella/artella-plugins-getdependencies/workflows/Create%20Release/badge.svg
    :target: https://github.com/artella/artella-plugins-getdependencies/actions?query=workflow%3A%22Create+Release%22

.. image:: https://img.shields.io/pypi/v/artella-plugins-getdependencies?branch=master&kill_cache=1
    :target: https://pypi.org/project/artella-plugins-getdependencies

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/